@@ -32,8 +32,11 @@
 #include <generic/apt/config_signal.h>
 #include <generic/apt/download_queue.h>
 #include <generic/apt/pkg_changelog.h>
+#include <generic/util/util.h>
 
 // System includes:
+#include <cwidget/generic/util/ssprintf.h>
+
 #include <apt-pkg/error.h>
 #include <apt-pkg/metaindex.h>
 #include <apt-pkg/progress.h>
@@ -61,11 +64,6 @@ using boost::shared_ptr;
 namespace
 {
 
-void set_name(temp::name n, temp::name *target)
-{
-  *target = n;
-}
-
   // Temporary hack to display download progress for a single file.
   //
   // Eventually there should be a generic class to track the progress
@@ -184,25 +182,51 @@ void set_name(temp::name n, temp::name *target)
     }
   };
 
-  void get_changelog(const pkgCache::VerIterator &ver,
+
+  /** \brief Get a package's changelog.
+   *
+   *  \param info Structure with the information needed to get the changelog
+   *  \param out_changelog_file  Where to store the resulting file.
+   *  \param term_metrics Data about the terminal
+   *
+   *  This routine exits once the download is complete.
+   */
+  void get_changelog(const boost::shared_ptr<aptitude::apt::changelog_info>& info,
 		     temp::name &out_changelog_file,
-                     const shared_ptr<terminal_metrics> &term_metrics)
+		     const shared_ptr<terminal_metrics> &term_metrics)
   {
-    const std::string short_description =
-      (boost::format("Changelog of %s") % ver.ParentPkg().Name()).str();
+    const std::string short_description = cwidget::util::ssprintf(_("Changelog of %s"), info->get_display_name().c_str());
 
     boost::shared_ptr<changelog_download_callbacks>
       callbacks = boost::make_shared<changelog_download_callbacks>(boost::ref(out_changelog_file),
 								   short_description,
                                                                    term_metrics);
 
-    get_changelog(aptitude::apt::changelog_info::create(ver),
-		  callbacks,
-		  aptitude::cmdline::post_thunk);
+    aptitude::apt::get_changelog(info, callbacks, aptitude::cmdline::post_thunk);
 
     aptitude::cmdline::main_loop();
   }
 
+  /** \brief Get a package's changelog.
+   *
+   *  \param ver Version iterator for which to get the changelog
+   *  \param out_changelog_file  Where to store the resulting file.
+   *  \param term_metrics Data about the terminal
+   *
+   *  This routine exits once the download is complete.
+   */
+  void get_changelog(const pkgCache::VerIterator &ver,
+		     temp::name &out_changelog_file,
+                     const shared_ptr<terminal_metrics> &term_metrics)
+  {
+    boost::shared_ptr<aptitude::apt::changelog_info> info =
+      aptitude::apt::changelog_info::create(ver);
+
+    get_changelog(info,
+		  out_changelog_file,
+		  term_metrics);
+  }
+
   /** \brief download a source package's changelog.
    *
    *  \param srcpkg the source package name
@@ -222,25 +246,14 @@ void set_name(temp::name n, temp::name *target)
 				 temp::name &out_changelog_file,
                                  const shared_ptr<terminal_metrics> &term_metrics)
   {
-    const std::string short_description =
-      (boost::format("Changelog of %s") % name).str();
-
-    boost::shared_ptr<changelog_download_callbacks>
-      callbacks = boost::make_shared<changelog_download_callbacks>(boost::ref(out_changelog_file),
-								   short_description,
-                                                                   term_metrics);
-
-    boost::shared_ptr<aptitude::apt::changelog_info>
-      info = aptitude::apt::changelog_info::create(srcpkg, ver, section, name);
+    boost::shared_ptr<aptitude::apt::changelog_info> info =
+      aptitude::apt::changelog_info::create(srcpkg, ver, section, name);
 
     get_changelog(info,
-		  callbacks,
-		  aptitude::cmdline::post_thunk);
-
-    aptitude::cmdline::main_loop();
+		  out_changelog_file,
+		  term_metrics);
   }
 
-
 /** Try to find a particular package version without knowing the
  *  section that it occurs in.  The resulting name will be invalid if
  *  no changelog could be found.
@@ -284,7 +297,7 @@ void do_cmdline_changelog(const vector<string> &packages,
 
       pager=getenv("PAGER");
 
-      if(pager==NULL)
+      if(strempty(pager)==true)
 	pager="more";
     }
 
@@ -325,7 +338,8 @@ void do_cmdline_changelog(const vector<string> &packages,
 	      for(pkgCache::VerFileIterator vf=ver.FileList();
 		  !vf.end() && !in_debian; ++vf)
 		if(!vf.File().end() && vf.File().Origin()!=NULL &&
-		   strcmp(vf.File().Origin(), "Debian")==0)
+		   (strcmp(vf.File().Origin(), "Debian")==0 ||
+		    strcmp(vf.File().Origin(), "Debian Backports")==0))
 		  in_debian=true;
 
 	      if(!in_debian)
@@ -352,7 +366,7 @@ void do_cmdline_changelog(const vector<string> &packages,
 	      get_changelog_from_source(p.get_package(),
 					p.get_version(),
 					p.get_section(),
-					pkg.Name(),
+					p.get_package(),
 					filename,
                                         term_metrics);
 	    }
