@@ -49,6 +49,7 @@
 #include <apt-pkg/sourcelist.h>
 #include <apt-pkg/version.h>
 #include <apt-pkg/aptconfiguration.h>
+#include <apt-pkg/fileutl.h>
 
 #include <fstream>
 
@@ -160,7 +161,7 @@ void apt_preinit(const char *rootdir)
   theme_config=new Configuration;
   user_config=new Configuration;
 
-  if(rootdir != NULL)
+  if(strempty(rootdir) == false)
     {
       _config->Set("RootDir", rootdir);
       theme_config->Set("RootDir", rootdir);
@@ -174,7 +175,7 @@ void apt_preinit(const char *rootdir)
 
   ReadConfigFile(*_config, PKGDATADIR "/section-descriptions");
 
-  // ForTranslators: Set this string to the name of a configuration
+  // TRANSLATORS: Set this string to the name of a configuration
   // file in $pkgdatadir/aptitude that overrides defaults for your
   // language.  This is particularly intended for overriding entries
   // in the Aptitude::Sections::Descriptions tree.
@@ -195,7 +196,7 @@ void apt_preinit(const char *rootdir)
 
   string cfgloc;
 
-  if(HOME != NULL && *HOME != '\0' &&
+  if(strempty(HOME) == false &&
      access((string(HOME) + "/.aptitude").c_str(), R_OK | X_OK) == 0)
     cfgloc = string(HOME) + "/.aptitude/config";
   else
@@ -248,7 +249,7 @@ void apt_dumpcfg(const char *root)
   string cfgloc;
 
   const char *HOME = getenv("HOME");
-  if(HOME != NULL && *HOME != '\0')
+  if(strempty(HOME) == false)
     {
       string tmp(HOME);
       tmp += "/.aptitude";
@@ -486,11 +487,7 @@ void apt_load_cache(OpProgress *progress_bar, bool do_initselections,
   LOG_TRACE(logger, "Loading task information.");
   aptitude::apt::load_tasks(*progress_bar);
   LOG_TRACE(logger, "Loading tags.");
-#ifndef HAVE_EPT
-  load_tags(*progress_bar);
-#else
-  aptitude::apt::load_tags();
-#endif
+  aptitude::apt::load_tags(progress_bar);
 
   if(user_pkg_hier)
     {
@@ -507,7 +504,7 @@ void apt_load_cache(OpProgress *progress_bar, bool do_initselections,
   // ~/.aptitude/cache; it has 512Kb of in-memory cache and 10MB of
   // on-disk cache.
   const char *HOME = getenv("HOME");
-  if(HOME != NULL)
+  if(strempty(HOME) == false)
     {
       std::string download_cache_file_name = string(HOME) + "/.aptitude/cache";
       const int download_cache_memory_size =
