@@ -35,17 +35,7 @@
 
 #include <cwidget/generic/util/transcode.h>
 
-#ifdef HAVE_EPT_TEXTSEARCH
-#include <ept/textsearch/textsearch.h>
-#else
-#ifdef HAVE_EPT_AXI
-#include <ept/axi/axi.h>
-#else
-#error "Don't know how to use the debtags Xapian database."
-#endif
-#endif
-
-#include <xapian/enquire.h>
+#include <xapian.h>
 
 #include <algorithm>
 
@@ -53,6 +43,7 @@
 #include <boost/unordered_map.hpp>
 
 #include "serialize.h"
+#include "../config_signal.h"
 
 using aptitude::util::progress_info;
 using boost::unordered_map;
@@ -65,26 +56,10 @@ namespace aptitude
   {
     namespace
     {
-#ifdef HAVE_EPT_TEXTSEARCH
-      typedef ept::textsearch::TextSearch debtags_db;
-
-      const Xapian::docid get_docid_by_name(const debtags_db &db,
-                                            const char *name)
-      {
-        return db.docidByName(name);
-      }
-
-      const Xapian::Database &get_xapian_db(const debtags_db &db)
-      {
-        return db.db();
-      }
-#endif
-
-#ifdef HAVE_EPT_AXI
       typedef Xapian::Database debtags_db;
 
-      const Xapian::docid get_docid_by_name(const debtags_db &db,
-                                            const char *name)
+      Xapian::docid get_docid_by_name(const debtags_db &db,
+				      const char *name)
       {
         std::string term = "XP";
         term += name;
@@ -100,7 +75,6 @@ namespace aptitude
       {
         return db;
       }
-#endif
 
       /** \brief Evaluate any regular expression-based pattern.
        *
@@ -407,15 +381,10 @@ namespace aptitude
       {
 	try
 	  {
-#ifdef HAVE_EPT_TEXTSEARCH
-	    db.reset(new ept::textsearch::TextSearch);
-#else
-#ifdef HAVE_EPT_AXI
-            db.reset(new Xapian::Database(ept::axi::path_db()));
-#else
-#error "Can't figure out how to create the debtags database."
-#endif
-#endif
+            const std::string filename =
+              aptcfg->FindFile("Apt-Xapian-Index::Index",
+                               "/var/lib/apt-xapian-index/index");
+            db.reset(new Xapian::Database(filename));
 	  }
 	catch(...)
 	  {
@@ -933,7 +902,7 @@ namespace aptitude
 	    // If this assert fails, something went wrong internally.
 	    {
 	      const std::size_t variable_index = p->get_bind_variable_index();
-	      eassert(variable_index >= 0 && variable_index < the_stack.size());
+	      eassert(variable_index < the_stack.size());
 
 	      ref_ptr<structural_match>
 		sub_match(evaluate_toplevel(structural_eval_any,
@@ -1140,7 +1109,7 @@ namespace aptitude
 	  case pattern::equal:
 	    {
 	      const std::size_t variable_index = p->get_equal_stack_position();
-	      eassert(variable_index >= 0 && variable_index < the_stack.size());
+	      eassert(variable_index < the_stack.size());
 
 	      // Search for the incoming package/version in the pool
 	      // referenced by this pattern.
@@ -1633,29 +1602,19 @@ namespace aptitude
 	    {
 	      pkgCache::PkgIterator pkg(target.get_package_iterator(cache));
 
-#ifdef HAVE_EPT
               using aptitude::apt::get_fullname;
 	      using aptitude::apt::get_tags;
-              using aptitude::apt::tag;
-#endif
+              using aptitude::apt::tag_set;
 
-#ifdef HAVE_EPT
-	      const std::set<tag> realTags(get_tags(pkg));
-	      const std::set<tag> * const tags(&realTags);
-#else
-	      const std::set<tag> * const tags(get_tags(pkg));
-#endif
+	      const tag_set tags(get_tags(pkg));
 
-	      if(tags == NULL)
+	      if(tags.empty() == true)
 		return NULL;
 
-	      for(std::set<tag>::const_iterator i=tags->begin(); i!=tags->end(); ++i)
+              for(tag_set::const_iterator i = tags.begin();
+                  i != tags.end(); ++i)
 		{
-#ifdef HAVE_EPT
-		  std::string name(get_fullname(*i));
-#else
-		  const std::string name = i->str().c_str();
-#endif
+		  const std::string name(get_fullname(*i));
 		  ref_ptr<match> rval =
 		    evaluate_regexp(p,
 				    p->get_tag_regex_info(),
