@@ -384,7 +384,7 @@ void resolver_manager::write_test_control_file(const std::string &outDir,
 
 	typedef generic_choice_set<aptitude_universe> choice_set;
 	typedef generic_choice<aptitude_universe> choice;
-	typedef aptitude_resolver_package package;
+	// typedef aptitude_resolver_package package;
 	typedef aptitude_resolver_version version;
 	typedef aptitude_resolver_dep dep;
 	const choice_set &choices = sol.get_choices();
@@ -1609,7 +1609,7 @@ void resolver_manager::select_solution(unsigned int solnum)
   cwidget::threads::mutex::lock l(mutex);
 
   cwidget::threads::mutex::lock sol_l(solutions_mutex);
-  if(solnum >= 0 && solnum <= solutions.size())
+  if(solnum <= solutions.size())
     selected_solution = solnum;
   sol_l.release();
 
