@@ -259,22 +259,21 @@ void pkg_grouppolicy_section::add_package(const pkgCache::PkgIterator &pkg,
   bool may_passthrough = false;
 
   string section;
-  if(!strncmp(pkg.Name(), "task-", 5))
-    {
-      section=_("Tasks");
-      may_passthrough = true;
-    }
-  else if(pkg.VersionList().end())
+  if(pkg.VersionList().end())
     {
       section=_("virtual");
       may_passthrough = true;
     }
-  else if(!pkg.VersionList().Section() ||
-	  (*pkg.VersionList().Section()) == '\0')
+  else if(strempty(pkg.VersionList().Section()) == true)
     {
       section=_("Unknown");
       may_passthrough = true;
     }
+  else if(strcmp(pkg.VersionList().Section(), "tasks") == 0)
+    {
+      section=_("Tasks");
+      may_passthrough = true;
+    }
   else
     {
       section=pkg.VersionList().Section();
@@ -802,7 +801,7 @@ public:
       }
 
     // Some packages don't have a reasonable priority
-    if(!pstr)
+    if(strempty(pstr)==true)
       {
 	pstr=_("unknown");
 	priority=0;
@@ -1096,8 +1095,6 @@ public:
 void pkg_grouppolicy_task::add_package(const pkgCache::PkgIterator &pkg,
 				       pkg_subtree *root)
 {
-  using aptitude::apt::task_list;
-
   set<string> *tasks = aptitude::apt::get_tasks(pkg);
 
   eassert(tasks);
@@ -1247,10 +1244,10 @@ private:
 		    ++i;
 		  }
 
-		wchar_t *endptr = NULL;
+		wchar_t *endptr;
 		unsigned long val = wcstoul(tocvt.c_str(), &endptr, 0);
 
-		if(endptr && (*endptr) != L'\0')
+		if(*endptr != L'\0')
 		  {
 		    wchar_t buf[512];
 
@@ -1399,29 +1396,21 @@ public:
   virtual void add_package(const pkgCache::PkgIterator &pkg,
 			   pkg_subtree *root)
   {
-#ifdef HAVE_EPT
     using aptitude::apt::get_facet_name;
     using aptitude::apt::get_tag_long_description;
     using aptitude::apt::get_tag_name;
     using aptitude::apt::get_tag_short_description;
     using aptitude::apt::get_tags;
-    using aptitude::apt::tag;
-#endif
+    using aptitude::apt::tag_set;
 
-#ifdef HAVE_EPT
-    const set<tag> realTags(get_tags(pkg));
-    const set<tag> * const tags(&realTags);
-#else
-    const set<tag> * const tags(get_tags(pkg));
-#endif
+    const tag_set tags(get_tags(pkg));
 
-    if(tags != NULL)
+    if(tags.empty() == true)
       return;
 
-    for(set<tag>::const_iterator ti = tags->begin();
-	ti != tags->end(); ++ti)
+    for(tag_set::const_iterator ti = tags.begin();
+	ti != tags.end(); ++ti)
       {
-#ifdef HAVE_EPT
         const std::string thisfacet = get_facet_name(*ti);
 
 	// Don't create items for tags that aren't in our facet.
@@ -1432,23 +1421,6 @@ public:
 	// call it?
 	std::string tagname = get_tag_name(*ti);
 
-#else // HAVE_EPT
-	tag::const_iterator j = ti->begin();
-	if(j == ti->end())
-	  continue;
-
-	string thisfacet = *j;
-
-	if(thisfacet != match_facet)
-	  continue;
-
-	++j;
-	if(j == ti->end())
-	  continue;
-
-	string tagname = *j;
-#endif // HAVE_EPT
-
 	childmap::const_iterator found =
 	  children.find(tagname);
 
@@ -1457,13 +1429,8 @@ public:
 
 	if(found == children.end())
 	  {
-#ifdef HAVE_EPT
 	    const std::string desc = get_tag_long_description(*ti);
 	    const std::string shortdesc = get_tag_short_description(*ti);
-#else // HAVE_EPT
-	    string desc = tag_description(ti->str());
-	    string shortdesc(desc, 0, desc.find('\n'));
-#endif
 
 	    subtree = new pkg_subtree(swsprintf(L"%s - %s",
 						tagname.c_str(),
@@ -1538,20 +1505,13 @@ public:
   virtual void add_package(const pkgCache::PkgIterator &pkg,
 			   pkg_subtree *root)
   {
-#ifdef HAVE_EPT
     using aptitude::apt::get_tags;
-    using aptitude::apt::tag;
-#endif
+    using aptitude::apt::tag_set;
 
-#ifdef HAVE_EPT
-    const set<tag> realTags(get_tags(pkg));
-    const set<tag> * const tags(&realTags);
-#else
-    const set<tag> * const tags(get_tags(pkg));
-#endif
+    const tag_set tags(get_tags(pkg));
 
     // Put all untagged, non-virtual packages into a separate list.
-    if((tags == NULL || tags->empty()) && !pkg.VersionList().end())
+    if(tags.empty() == true && !pkg.VersionList().end())
       {
 	if(untagged_tree == NULL)
 	  {
@@ -1569,13 +1529,12 @@ public:
 	untagged_policy->add_package(pkg, untagged_tree);
       }
 
-    if(tags == NULL)
+    if(tags.empty() == true)
       return;
 
-    for(set<tag>::const_iterator ti = tags->begin();
-	ti != tags->end(); ++ti)
+    for(tag_set::const_iterator ti = tags.begin();
+	ti != tags.end(); ++ti)
       {
-#ifdef HAVE_EPT
         using aptitude::apt::get_facet_long_description;
         using aptitude::apt::get_facet_name;
         using aptitude::apt::get_facet_short_description;
@@ -1583,25 +1542,8 @@ public:
         using aptitude::apt::get_tag_name;
         using aptitude::apt::get_tag_short_description;
 
-	std::string thisfacet(get_facet_name(*ti));
-	std::string thistag(get_tag_name(*ti));
-#else // HAVE_EPT
-	tag::const_iterator j = ti->begin();
-
-	eassert(j != ti->end());
-
-	string thisfacet = *j;
-
-	if(j != ti->end())
-	  ++j;
-
-	string thistag;
-
-	if(j == ti->end())
-	  thistag = _("MISSING TAG");
-	else
-	  thistag = *j;
-#endif
+	const std::string thisfacet(get_facet_name(*ti));
+	const std::string thistag(get_tag_name(*ti));
 
 	facetmap::const_iterator facetfound =
 	  children.find(thisfacet);
@@ -1611,13 +1553,8 @@ public:
 
 	if(facetfound == children.end())
 	  {
-#ifdef HAVE_EPT
-	    string desc(get_facet_long_description(*ti));
-	    string shortdesc(get_facet_short_description(*ti));
-#else // HAVE_EPT
-	    string desc = get_facet_description(*ti);
-	    string shortdesc(desc, 0, desc.find('\n'));
-#endif
+	    const string desc(get_facet_long_description(*ti));
+	    const string shortdesc(get_facet_short_description(*ti));
 
 	    if(!shortdesc.empty())
 	      tagtree = new pkg_subtree(swsprintf(L"%s - %s",
@@ -1649,13 +1586,8 @@ public:
 
 	if(tagfound == tagchildren->end())
 	  {
-#ifdef HAVE_EPT
-	    string desc(get_tag_long_description(*ti));
-	    string shortdesc(get_tag_short_description(*ti));
-#else // HAVE_EPT
-	    string desc = tag_description(ti->str());
-	    string shortdesc(desc, 0, desc.find('\n'));
-#endif
+	    const string desc(get_tag_long_description(*ti));
+	    const string shortdesc(get_tag_short_description(*ti));
 
 	    if(!shortdesc.empty())
 	      subtree = new pkg_subtree(swsprintf(L"%s - %s",
